@@ -1,5 +1,5 @@
 from typing import Optional
-from .app_data import AppDataKeys
+from .app_data import AppDataKeys, AppData
 from .main_dashboard import MainDashboard
 
 __all__ = ["CLEASEGui", "display_ui"]
@@ -12,7 +12,7 @@ class CLEASEGui:
 
         if app_data is None:
             # The default app data.
-            app_data = {AppDataKeys.DEV_MODE: dev_mode}
+            app_data = AppData(**{AppDataKeys.DEV_MODE: dev_mode})
         # We "write protect" these with property tags.
         self._app_data = app_data
         self._dashboard = MainDashboard(self.app_data)
