@@ -188,7 +188,7 @@ class MainDashboard(BaseDashboard):
     def _load_app_data(self, filename):
         new_data = load_app_data(filename)
         # Get the supercell, and make the supercell dashboard set it
-        supercell = self.app_data.pop(self.KEYS.SUPERCELL, None)
+        supercell = self.app_data.get(self.KEYS.SUPERCELL, None)
         if supercell is not None:
             logger.debug("Updating supercell from app data")
             dashboard = self.dashboards["supercell"]
