@@ -1,4 +1,6 @@
 import logging
+import time
+from datetime import timedelta
 import uuid
 from IPython.display import display, clear_output
 import ipywidgets as widgets
@@ -413,23 +415,30 @@ class CanonicalMC(BaseDashboard):
             mc.attach(self.step_move_obs)
         self.app_data[self.KEYS.STEP_OBSERVER] = self.step_move_obs
 
+        # Read in the number of steps.
+        steps = self.get_number_of_steps()
         # Initialize the progress bar
         self.mc_progress.value = 0
         self.mc_progress.max = n_temp
-
+        start_time = time.perf_counter()
+        logger.info("Starting MC with %d temperature steps, and %d swaps per step.", n_temp, steps)
         try:
             for ii, temp in enumerate(temperatures):
                 # Update progress bar
                 self.mc_progress.value += 1
                 prog = (ii + 1) / n_temp * 100  # Progress in percentage
+                runtime = time.perf_counter() - start_time
+                dt = timedelta(seconds=round(runtime))
                 self.mc_progress_label.value = (
-                    f"{prog:.1f}%, {ii+1}/{n_temp}. " f"Current temp: {temp:.1f} K"
+                    f"{prog:.1f}%, {ii+1}/{n_temp}. Runtime: {dt}. Current temp: {temp:.1f} K"
                 )
 
                 # Initialize MC things
                 check_abort(mc)
                 mc.T = temp
-                steps = self.get_number_of_steps()
+                # Ensure average energies are cleared.
+                _clear_energies(mc)
+
                 initial_energy = mc.current_energy
 
                 # some debugging logging
@@ -455,15 +464,15 @@ class CanonicalMC(BaseDashboard):
                     emin_obs.lowest_energy,
                 )
                 self._update_mc_data(mc, emin_obs, data)
-                # Update the atoms object to the current emin, and continue from that
-                atoms = emin_obs.emin_atoms
 
             if self.update_after_run:
-                # "atoms" is now the emin atoms
-                self.set_supercell(atoms)
+                # Set the supercell to the best atoms object we found.
+                self.set_supercell(emin_obs.emin_atoms)
                 logger.info("Updated supercell to minimum energy configuration")
 
-            logger.info("MC run complete.")
+            dt = timedelta(seconds=round(time.perf_counter() - start_time))
+            dt_per_step = dt / n_temp
+            logger.info("MC run complete in %s. Avg. time per temp: %s.", dt, dt_per_step)
         finally:
             self._mc = None
 
@@ -544,3 +553,10 @@ def make_spacing_boxes(min=300, max=30000, steps=25, style_kwargs=None):
         layout=dict(justify_content="space-between"),
     )
     return temp_range_box
+
+
+def _clear_energies(mc: clease.montecarlo.Montecarlo) -> None:
+    """Helper function to clear the avg energies in the MC object."""
+    for avger in [mc.mean_energy, mc.energy_squared]:
+        if avger is not None:
+            avger.clear()
