@@ -145,7 +145,7 @@ class SettingsMakerDashboard(BaseDashboard):
     @utils.disable_cls_widget("delete_settings_btn")
     def _on_delete_settings_click(self, b):
         try:
-            self.app_data.pop(self.KEYS.SETTINGS)
+            del self.app_data[self.KEYS.SETTINGS]
             logger.info("Removed settings from app data")
         except KeyError:
             logger.info("No settings in app data, cannot delete.")
